@@ -174,10 +174,11 @@ def skeletonize(packages, repo, output_dir=".", version=None, recursive=False,
     sources into expected conda recipe format."""
 
     version = getattr(config, "version", version)
+    #I dont now if these do anything
     if version:
         kwargs.update({'version': version})
     if recursive:
-        kwargs.update({'version': version})
+        kwargs.update({'recursive': recursive})
     if output_dir != ".":
         kwargs.update({'output_dir': output_dir})
 
